==> flrig_1.4.7.orig.tar.gz: flrig-1.4.7/src/include/yaesu/FT100D.h <==
// ----------------------------------------------------------------------------
// Copyright (C) 2014
//              David Freese, W1HKJ
//
// This file is part of flrig.
//
// flrig is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// flrig is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------

#ifndef FT100D_H
#define FT100D_H

#include "rigbase.h"

class RIG_FT100D : public rigbase {
private:
	double fwdpwr;
	double refpwr;
	double fwdv;
	double refv;
	int afreq, amode, aBW;
	int bfreq, bmode, bBW;

public:
	RIG_FT100D();
	~RIG_FT100D(){};
	
	void initialize();

	bool get_info();

	bool check();

	bool can_split() { return true;}
	void set_split(bool val);
	bool twovfos() {return false;}

	unsigned long int get_vfoA();
	void set_vfoA(unsigned long int);
	void set_modeA(int val);
	int  get_modeA();
	void set_bwA(int val);
	int  get_bwA();

	unsigned long int get_vfoB();
	void set_vfoB(unsigned long int);
	void set_modeB(int val);
	int  get_modeB();
	void set_bwB(int val);
	int  get_bwB();

	int  def_bandwidth(int m);

	void selectA();
	void selectB();

	void set_PTT_control(int val);
	int  get_smeter();
	int  get_swr();
	int  get_power_out();

	int  adjust_bandwidth(int);

private:
	void init_cmd();
};


#endif

==> flrig-2.0.09.tar.gz: flrig-2.0.09/src/include/yaesu/FT100D.h <==
// ----------------------------------------------------------------------------
// Copyright (C) 2014
//              David Freese, W1HKJ
//
// This file is part of flrig.
//
// flrig is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// flrig is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------

#ifndef FT100D_H
#define FT100D_H

#include "rigbase.h"

class RIG_FT100D : public rigbase {
private:
	double fwdpwr;
	double refpwr;
	double fwdv;
	double refv;
	int amode, aBW;
	int bmode, bBW;
	unsigned long long afreq;
	unsigned long long bfreq;

public:
	RIG_FT100D();
	~RIG_FT100D(){};
	
	void initialize();

	bool get_info();

	bool check();

	bool can_split() { return true;}
	void set_split(bool val);
	bool twovfos() {return false;}

	unsigned long long get_vfoA();
	void set_vfoA(unsigned long long);
	void set_modeA(int val);
	int  get_modeA();
	void set_bwA(int val);
	int  get_bwA();

	unsigned long long get_vfoB();
	void set_vfoB(unsigned long long);
	void set_modeB(int val);
	int  get_modeB();
	void set_bwB(int val);
	int  get_bwB();

	int  def_bandwidth(int m);

	void selectA();
	void selectB();

	void set_PTT_control(int val);
	int  get_smeter();
	int  get_swr();
	int  get_power_out();

	int  adjust_bandwidth(int);

private:
	void init_cmd();
};


#endif
